==> scotch-7.0.4-3-x86_64.pkg.tar.zst: usr/lib/cmake/scotch/scotchmetisTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "SCOTCH::scotchmetisv3" for configuration "Release"
set_property(TARGET SCOTCH::scotchmetisv3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SCOTCH::scotchmetisv3 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "SCOTCH::scotch"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libscotchmetisv3.so"
  IMPORTED_SONAME_RELEASE "libscotchmetisv3.so"
  )

list(APPEND _cmake_import_check_targets SCOTCH::scotchmetisv3 )
list(APPEND _cmake_import_check_files_for_SCOTCH::scotchmetisv3 "${_IMPORT_PREFIX}/lib/libscotchmetisv3.so" )

# Import target "SCOTCH::scotchmetisv5" for configuration "Release"
set_property(TARGET SCOTCH::scotchmetisv5 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SCOTCH::scotchmetisv5 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "SCOTCH::scotch"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libscotchmetisv5.so"
  IMPORTED_SONAME_RELEASE "libscotchmetisv5.so"
  )

list(APPEND _cmake_import_check_targets SCOTCH::scotchmetisv5 )
list(APPEND _cmake_import_check_files_for_SCOTCH::scotchmetisv5 "${_IMPORT_PREFIX}/lib/libscotchmetisv5.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> scotch-7.0.5-2-x86_64.pkg.tar.zst: usr/lib/cmake/scotch/scotchmetisTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "SCOTCH::scotchmetisv3" for configuration "Release"
set_property(TARGET SCOTCH::scotchmetisv3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SCOTCH::scotchmetisv3 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "SCOTCH::scotch"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libscotchmetisv3.so.7.0.5"
  IMPORTED_SONAME_RELEASE "libscotchmetisv3.so.7.0"
  )

list(APPEND _cmake_import_check_targets SCOTCH::scotchmetisv3 )
list(APPEND _cmake_import_check_files_for_SCOTCH::scotchmetisv3 "${_IMPORT_PREFIX}/lib/libscotchmetisv3.so.7.0.5" )

# Import target "SCOTCH::scotchmetisv5" for configuration "Release"
set_property(TARGET SCOTCH::scotchmetisv5 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SCOTCH::scotchmetisv5 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "SCOTCH::scotch"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libscotchmetisv5.so.7.0.5"
  IMPORTED_SONAME_RELEASE "libscotchmetisv5.so.7.0"
  )

list(APPEND _cmake_import_check_targets SCOTCH::scotchmetisv5 )
list(APPEND _cmake_import_check_files_for_SCOTCH::scotchmetisv5 "${_IMPORT_PREFIX}/lib/libscotchmetisv5.so.7.0.5" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
